@@ -3,9 +3,7 @@ import os
 from importlib import import_module
 from distutils.dir_util import copy_tree
 from types import ModuleType
-from flask.app import Flask
-from jinja2 import Template
-from flask import current_app
+from flask import current_app, Flask, render_template
 from flask_sqlalchemy import Model
 
 from .exception import ZemfrogTemplateNotFound, ZemfrogModelNotFound
@@ -13,19 +11,19 @@ from .exception import ZemfrogTemplateNotFound, ZemfrogModelNotFound
 TEMPLATE_DIR = os.path.join(os.path.dirname(__file__), "templates")
 
 
-def get_template(name: str) -> str:
+def get_template(*paths) -> str:
     """
     Function to get template base directory.
 
-    :param name: template directory name.
+    :param paths: template directory or file name.
 
     :raises: ZemfrogTemplateNotFound
 
     """
 
-    t = os.path.join(TEMPLATE_DIR, name)
-    if not os.path.isdir(t):
-        raise ZemfrogTemplateNotFound("unknown template %r" % name)
+    t = os.path.join(TEMPLATE_DIR, *paths)
+    if not (os.path.isdir(t) or os.path.isfile(t)):
+        raise ZemfrogTemplateNotFound("unknown template %r" % os.sep.join(paths))
 
     return t
 
@@ -138,19 +136,9 @@ def get_mail_template(name, **context):
     :param name: email template name.
     :param \*\*context: jinja context.
 
-    :raises: ZemfrogTemplateNotFound
-
     """
 
-    tmp_src = os.path.join(current_app.root_path, "mail", name)
-    if not os.path.isfile(tmp_src):
-        raise ZemfrogTemplateNotFound("Email template %r was not found" % tmp_src)
-
-    with open(tmp_src) as fp:
-        data = fp.read()
-
-    t = Template(data)
-    tmp = t.render(**context)
+    tmp = render_template("emails/" + name, **context)
     return tmp
 
 
