@@ -1,19 +1,21 @@
 import os
 from glob import glob
 from importlib import import_module
-from os import getenv
 from typing import Dict, List
 
+
 import pkg_resources
+import click
 from flask import Flask
 from flask.blueprints import Blueprint
 from flask.cli import load_dotenv, routes_command, run_command, shell_command
-from flask_apispec import FlaskApiSpec, doc
+from flask_apispec import FlaskApiSpec
 from werkzeug.middleware.dispatcher import DispatcherMiddleware
 
 from .exception import ZemfrogEnvironment
-from .generator import g_schema
+from .decorators import api_doc
 from .helper import get_import_name, get_models, import_attr
+from .repl import build_repl
 
 
 def load_config(app: Flask):
@@ -24,7 +26,7 @@ def load_config(app: Flask):
 
     path = os.path.join(app.root_path, ".flaskenv")
     load_dotenv(path)
-    env = getenv("ZEMFROG_ENV")
+    env = os.getenv("ZEMFROG_ENV")
     if not env:
         raise ZemfrogEnvironment("environment not found")
 
@@ -159,6 +161,18 @@ def load_apis(app: Flask):
     app.register_blueprint(api)
 
 
+def load_error_handlers(app: Flask):
+    """
+    Function to load all error handlers
+    """
+
+    import_name = get_import_name(app)
+    handlers = app.config.get("ERROR_HANDLERS", {})
+    for code, view in handlers.items():
+        view = import_attr(import_name + view + ".handler")
+        app.register_error_handler(code, view)
+
+
 def load_services(app: Flask):
     """
     Function to load all celery tasks based on ``SERVICES`` configuration in config.py.
@@ -170,15 +184,6 @@ def load_services(app: Flask):
         import_module(import_name + sv)
 
 
-def load_schemas(app: Flask):
-    """
-    A function to create marshmallow schema models automatically for all your ORM models.
-    """
-
-    for src, models in app.models.items():
-        g_schema(src, models)
-
-
 def load_docs(app: Flask):
     """
     Function for creating api docs using ``flask-apispec``.
@@ -190,24 +195,24 @@ def load_docs(app: Flask):
     import_name = get_import_name(app)
     docs: FlaskApiSpec = import_attr(import_name + "extensions.apispec.docs")
     urls = import_module(import_name + "urls")
-    api_docs = urls.docs
+    docs_params = urls.docs
     routes = urls.routes
     for _, view, _ in routes:
-        if api_docs:
-            view = doc(**api_docs)(view)
+        if docs_params:
+            view = api_doc(**docs_params)(view)
         docs.register(view)
 
     apis = app.config.get("APIS", [])
     for res in apis:
         res = import_module(import_name + res)
-        api_docs = res.docs
+        docs_params = res.docs
         routes = res.routes
         endpoint = res.endpoint
         for detail in routes:
             _, view, _ = detail
             e = endpoint + "_" + view.__name__
-            if api_docs:
-                view = doc(**api_docs)(view)
+            if docs_params:
+                view = api_doc(**docs_params)(view)
             docs.register(view, endpoint=e, blueprint="api")
 
     blueprints = app.config.get("BLUEPRINTS", [])
@@ -216,11 +221,11 @@ def load_docs(app: Flask):
         bp: Blueprint = import_attr(bp)
         urls = import_name + name + ".urls"
         urls = import_module(urls)
-        api_docs = urls.docs
+        docs_params = urls.docs
         routes = urls.routes
         for _, view, _ in routes:
-            if api_docs:
-                view = doc(**api_docs)(view)
+            if docs_params:
+                view = api_doc(**docs_params)(view)
             docs.register(view, blueprint=name)
 
 
@@ -239,7 +244,11 @@ def load_apps(app: Flask):
         path = a.get("path", "/" + name)
         help = a.get("help", "")
         yourapp: Flask = import_attr(name + ".wsgi.app")
-        cli = yourapp.cli
+
+        @click.command(name)
+        def cli():
+            build_repl(yourapp)
+
         cli.help = help
         app.cli.add_command(cli, name)
         mounts[path] = yourapp
