@@ -13,6 +13,14 @@ class Development(object):
     MAIL_DEFAULT_SENDER = "admin@localhost.com"
     APISPEC_TITLE = "API Docs"
     APISPEC_SWAGGER_UI_URL = "/docs"
+    APISPEC_SECURITY_DEFINITIONS = {
+        "Bearer": {
+            "type": "oauth2",
+            "flow": "password",
+            "tokenUrl": "/auth/jwt/login",
+        }
+    }
+    APISPEC_SECURITY_PARAMS = [{"Bearer": []}]
     DEBUG = True
     {% if main_app -%}
         APPS = []
@@ -30,8 +38,8 @@ class Development(object):
         "zemfrog.commands.api",
         "zemfrog.commands.blueprint",
         "zemfrog.commands.middleware",
-        "zemfrog.commands.schema",
         "zemfrog.commands.command",
+        "zemfrog.commands.errorhandler",
         {% if main_app -%}
             "zemfrog.commands.app"
         {%- endif %}
@@ -39,6 +47,7 @@ class Development(object):
     BLUEPRINTS = ["auth"]
     MIDDLEWARES = []
     APIS = []
+    ERROR_HANDLERS = {}
     API_DOCS = True
     CREATE_DB = True
     CELERY_RESULT_BACKEND = "redis://127.0.0.1:6379"
