@@ -1,4 +1,4 @@
 from zemfrog.app import create_app, make_celery
 
-app = create_app(__name__)
+app = create_app("{{import_name}}")
 celery = make_celery(app)
